An implementation-agnostic implementation of JSON reference resolution.

In other words, a way for e.g. JSON Schema tooling to resolve the ``$ref`` keyword across all drafts without needing to implement support themselves.

.. toctree::
    :glob:
    :hidden:

    intro
    external-retrieval
    schema-packages
    api
    changes
    compatibility
